@@ -1,9 +1,10 @@
 /*! ========================================================================
 ** Extended Template and Library
 ** Surface Class Implementation
-** $Id: _surface.h 659 2007-09-12 21:01:33Z dooglus $
+** $Id$
 **
 ** Copyright (c) 2002 Robert B. Quattlebaum Jr.
+** Copyright (c) 2008 Chris Moore
 **
 ** This package is free software; you can redistribute it and/or
 ** modify it under the terms of the GNU General Public License as
@@ -32,6 +33,7 @@
 #include "_pen.h"
 #include "_misc.h"
 #include <algorithm>
+#include <cstring>
 
 /* === M A C R O S ========================================================= */
 
@@ -64,7 +66,7 @@ public:
 	typedef VP value_prep_type;
 
 	typedef alpha_pen<const_pen> const_alpha_pen;
-	typedef alpha_pen<pen> alpha_pen;
+	typedef alpha_pen<pen> non_const_alpha_pen;
 
 	typedef typename pen::difference_type size_type;
 	typedef typename pen::difference_type difference_type;
